@@ -24,39 +24,6 @@ my $matrixwidgetvisualcell = {};
 my $matrixwidgetdatacell = {};
 my $cui = undef;
 
-my @keys_move = ( #FIXME now we catch all chars not only keys_move. So this remains for documenation only.
-                  "h", KEY_LEFT(),
-                  "j", KEY_DOWN(),
-                  "k", KEY_UP(),
-                  "l", KEY_RIGHT(),
-                       KEY_NPAGE(),
-                       KEY_PPAGE(),
-                       KEY_HOME(),
-                       KEY_END(),
-                       KEY_ENTER(), #same as F2
-                       KEY_F(1),    #help
-                       KEY_F(2),    #edit
-                  "o", KEY_F(3),    #on a new line
-                  "O", KEY_F(4),    #On a new line
-                  "d", KEY_F(5),    #delete line
-                       #KEY_F(6),    #copy line
-                       KEY_F(7),    #column show/hide
-                       KEY_F(8),    #column sorting
-                       KEY_F(9),    #column shrink to min
-                       KEY_F(10),   #column shrink
-                       KEY_F(11),   #column grow
-                       KEY_F(12),   #column grow to max
-                  "1",              #scroll screen up to the top and place cursor on the first line
-                  "G",              #scroll screen down to the bottom and place cursor on the last line
-                  "\cU",            #scroll screen up, cursor stays at current position
-                       KEY_DC(),    #scroll screen down, cursor stays at current position
-                  "^",              #scroll screen left to the border and place cursor on the first cell
-                  "\$",             #scroll screen right to the border and place cursor on the last cell
-                  "y",              #yank
-                  "p",              #paste
-                  "P"               #Paste
-);
-
 sub rightmostvisiblefit {
     my $c;
     my $lastc;
@@ -676,7 +643,7 @@ sub keybinder {
             $vr = 0;
         }
     }
-    elsif ($key == KEY_DOWN() or (not $editcell and $key eq "j")) {
+    elsif ($key == KEY_DOWN() or $key eq "j") {
         $vr++;
         if ($vr > $nvr) {
             $vrscroll = 1;
@@ -693,14 +660,14 @@ sub keybinder {
             $vr = $nvr;
         }
     }
-    elsif (not $editcell and ($key == KEY_LEFT() or $key eq "h")) {
+    elsif ($key == KEY_LEFT() or $key eq "h") {
         $vc--;
         if ($vc < 0) {
             $vcscroll = -1;
             $vc = 0;
         }
     }
-    elsif (not $editcell and ($key == KEY_RIGHT() or $key eq "l")) {
+    elsif ($key == KEY_RIGHT() or $key eq "l") {
         $vc++;
         if ($vc > $nvc) {
             $vcscroll = 1;
@@ -715,66 +682,76 @@ sub keybinder {
         $vr = $nvr;
         $vc = $nvc;
     }
-    elsif (not $editcell and ($key eq "^" or $key eq "0")) {
+    elsif ($key eq "^" or $key eq "0") {
         $vc = 0;
         $vcpos = -1;
     }
-    elsif (not $editcell and $key eq "\$") {
+    elsif ($key eq "\$") {
         $vc = $nvc;
         $vcpos = +1;
     }
-    elsif (not $editcell and $key eq "1") {
+    elsif ($key eq "1") {
         $vr = 0;
         $vrpos = -1;
     }
-    elsif (not $editcell and $key eq "G") {
+    elsif ($key eq "G") {
         $vr = $nvr;
         $vrpos = +1;
     }
-    elsif (not $editcell and $key eq "\cU") {
+    elsif ($key eq "\cU") {
         my $j;
         $j = int($matrixwidget->{"NumVisualRow"} / 3 * 1);
         $j = 10 if ( $j < 10 );
         $vrscroll = -$j;
     }
-    elsif (not $editcell and $key eq "\cD") {
+    elsif ($key eq "\cD") {
         my $j;
         $j = int($matrixwidget->{"NumVisualRow"} / 3 * 1);
         $j = 10 if ( $j < 10 );
         $vrscroll = +$j;
     }
-    elsif (not $editcell and $key eq "\cB") {
+    elsif ($key eq "\cB") {
         $vrscroll = -$matrixwidget->{"NumVisualRow"};
     }
-    elsif (not $editcell and $key eq "\cF") {
+    elsif ($key eq "\cF") {
         $vrscroll = +$matrixwidget->{"NumVisualRow"};
     }
     elsif ($key == KEY_F(1)) {
-        $this->root->dialog(
-                     "\n     ==== action ====\n" .
-                     "      CTRL-X - menu\n" .
-                     "      CTRL-Q - save and quit\n" .
-                     "          F1 - help\n" .
-                     "      RET/F2 - edit existing line\n" .
-                     "        o/F3 - edit on new next line\n" .
-                     "        O/F4 - edit on new this line\n" .
-                     "        d/F5 - mark line for deletion\n" .
-                     "\n     ==== control column view ====\n" .
-                     "          F7 - show/hide\n" .
-                     "          F8 - sort\n" .
-                     "          F9 - shrink to min\n" .
-                     "         F10 - shrink\n" .
-                     "         F11 - grow\n" .
-                     "         F12 - grow to max\n" .
-                     "\n     ==== movement ====\n" .
-                     " hjkl/CURSOR - left, down, up, right\n" .
-                     "PAGE UP/DOWN - move 10 line\n" .
-                     "         TAB - next cell\n" .
-                     "    HOME/END - jump to first/last cell\n"
-            );
-        return; #do not change focus
+        my $text = "";
+        my $io = new IO::File "<as-cui.help";
+        if (defined($io)) {
+            while (defined(my $ln = <$io>)) {
+                $text .= $ln;
+            }
+            $io->close();
+        }
+        else {
+            $text = "cannot open as-cui.help file";
+        }
+
+        my $w = $this->parent->add("help", 'TextViewer',
+            -x          => $matrixwidget->{"XOffset"},
+            -y          => $matrixwidget->{"YOffset"},
+            -width      => $matrixwidget->{"Width"},
+            -height     => $matrixwidget->{"Height"},
+            -border     => 1,
+            -title      => "Help",
+            -vscrollbar => 1,
+            -text       => $text
+        );
+        $w->set_binding(
+            sub {
+                my $this = shift;
+                my $key = shift;
+                $this->{-has_modal_focus} = 0;
+            },
+            KEY_ENTER());
+        $w->draw;
+        $w->modalfocus;
+        $this->parent->delete("help");
+        $datacoll = 1;
     }
-    elsif (not $editcell and ($key eq " ")) {
+    elsif ($key eq " ") {
         $matrixwidget->{"VC.$vc.$vr"}->{-text} = '';
         $matrixwidget->{"VC.$vc.$vr"}->{-pos} = 0;
         $matrixwidget->{"VC.$vc.$vr"}->{-canvasscr}->standend;
@@ -782,13 +759,13 @@ sub keybinder {
         $editcell = 1;
         return; #do not change focus
     }
-    elsif (not $editcell and ($key == KEY_F(2) or $key == KEY_ENTER)) {
+    elsif ($key == KEY_F(2) or $key == KEY_ENTER) {
         $matrixwidget->{"VC.$vc.$vr"}->{-canvasscr}->standend;
         $matrixwidget->{"VC.$vc.$vr"}->draw;
         $editcell = 1;
         return; #do not change focus
     }
-    elsif (not $editcell and ($key == KEY_F(3) or $key eq "o")) {
+    elsif ($key eq "o") {
         if (defined $matrixdata->{"onanewline"}) {
             my ($vc, $vr) = @{$matrixwidgetvisualcell->{$this->getfocusobj}};
             my ($dc, $dr) = @{$matrixwidgetdatacell->{$this->getfocusobj}};
@@ -803,7 +780,7 @@ sub keybinder {
             $vr = $nvr;
         }
     }
-    elsif (not $editcell and ($key == KEY_F(4) or $key eq "O")) {
+    elsif ($key eq "O") {
         if (defined $matrixdata->{"Onanewline"}) {
             my ($vc, $vr) = @{$matrixwidgetvisualcell->{$this->getfocusobj}};
             my ($dc, $dr) = @{$matrixwidgetdatacell->{$this->getfocusobj}};
@@ -813,7 +790,7 @@ sub keybinder {
         $this->root->feedkey(KEY_F(2)); #enter edit mode after datacoll was handled
         return; #do not change focus
     }
-    elsif (not $editcell and ($key == KEY_F(5) or $key eq "d")) {
+    elsif ($key eq "d") {
         if (defined $matrixdata->{"deletedelete"}) {
             my ($vc, $vr) = @{$matrixwidgetvisualcell->{$this->getfocusobj}};
             my ($dc, $dr) = @{$matrixwidgetdatacell->{$this->getfocusobj}};
@@ -829,7 +806,7 @@ sub keybinder {
         }
         return; #do not change focus
     }
-    elsif (not $editcell and $key eq "u") {
+    elsif ($key eq "u") {
         if (defined $matrixdata->{"undo"}) {
             my ($vc, $vr) = @{$matrixwidgetvisualcell->{$this->getfocusobj}};
             my ($dc, $dr) = @{$matrixwidgetdatacell->{$this->getfocusobj}};
@@ -954,7 +931,7 @@ sub keybinder {
         }
         return; #do not change focus
     }
-    elsif (not $editcell and $key eq "y") {
+    elsif ($key eq "y") {
         if (defined $matrixdata->{"yankcell"}) {
             my ($vc, $vr) = @{$matrixwidgetvisualcell->{$this->getfocusobj}};
             my ($dc, $dr) = @{$matrixwidgetdatacell->{$this->getfocusobj}};
@@ -962,7 +939,7 @@ sub keybinder {
             $datacoll = 1;
         }
     }
-    elsif (not $editcell and $key eq "Y") {
+    elsif ($key eq "Y") {
         if (defined $matrixdata->{"Yankline"}) {
             my ($vc, $vr) = @{$matrixwidgetvisualcell->{$this->getfocusobj}};
             my ($dc, $dr) = @{$matrixwidgetdatacell->{$this->getfocusobj}};
@@ -970,7 +947,7 @@ sub keybinder {
             $datacoll = 1;
         }
     }
-    elsif (not $editcell and $key eq "p") {
+    elsif ($key eq "p") {
         if (defined $matrixdata->{"paste"} and $matrixdata->{"clipboardtype"} eq "cell") {
             my ($vc, $vr) = @{$matrixwidgetvisualcell->{$this->getfocusobj}};
             my ($dc, $dr) = @{$matrixwidgetdatacell->{$this->getfocusobj}};
@@ -989,7 +966,7 @@ sub keybinder {
             }
         }
     }
-    elsif (not $editcell and $key eq "P") {
+    elsif ($key eq "P") {
         if (defined $matrixdata->{"Paste"}) {
             my ($vc, $vr) = @{$matrixwidgetvisualcell->{$this->getfocusobj}};
             my ($dc, $dr) = @{$matrixwidgetdatacell->{$this->getfocusobj}};
@@ -999,7 +976,7 @@ sub keybinder {
         #$this->root->feedkey(KEY_F(2)); #enter edit mode after datacoll was handled
         return; #do not change focus
     }
-    elsif (not $editcell and $key eq ".") {
+    elsif ($key eq ".") {
         if (defined $matrixdata->{"currentdatetime"}) {
             my ($vc, $vr) = @{$matrixwidgetvisualcell->{$this->getfocusobj}};
             my ($dc, $dr) = @{$matrixwidgetdatacell->{$this->getfocusobj}};
